@@ -54,7 +54,7 @@
  */
 
 //! PAL Device Implementation
-namespace pal {
+namespace amd::pal {
 
 //! A nil device object
 class NullDevice : public amd::Device {
@@ -145,9 +145,9 @@ class NullDevice : public amd::Device {
   }
   virtual void svmFree(void* ptr) const { return; }
   virtual void* virtualAlloc(void* addr, size_t size, size_t alignment) { return nullptr; };
-  virtual void virtualFree(void* addr) { };
+  virtual bool virtualFree(void* addr) { return true; }
 
-  virtual bool SetMemAccess(void* va_addr, size_t va_size, VmmAccess access_flags, size_t count) {
+  virtual bool SetMemAccess(void* va_addr, size_t va_size, VmmAccess access_flags) {
     return true;
   }
 
@@ -155,6 +155,15 @@ class NullDevice : public amd::Device {
     return true;
   }
 
+  virtual bool ExportShareableVMMHandle(amd::Memory& amd_mem_obj, int flags,
+                                        void* shareableHandle) {
+    return false;
+  }
+
+  virtual amd::Memory* ImportShareableVMMHandle(void* osHandle) {
+    return nullptr;
+  }
+
   virtual bool importExtSemaphore(void** extSemaphore,const amd::Os::FileDesc& handle,
                                   amd::ExternalSemaphoreHandleType sem_handle_type) override {
     return false;
@@ -546,16 +555,17 @@ class Device : public NullDevice {
   //! SVM free
   virtual void svmFree(void* ptr) const;
 
+  //! Virtual address space allocation(reservation)
   virtual void* virtualAlloc(void* addr, size_t size, size_t alignment);
-  virtual void virtualFree(void* addr);
+  virtual bool virtualFree(void* addr);
 
-  virtual bool SetMemAccess(void* va_addr, size_t va_size, VmmAccess access_flags, size_t count) {
-    return true;
-  }
+  //! Set/Get memory access set by the app
+  virtual bool SetMemAccess(void* va_addr, size_t va_size, VmmAccess access_flags);
+  virtual bool GetMemAccess(void* va_addr, VmmAccess* access_flags_ptr);
 
-  virtual bool GetMemAccess(void* va_addr, VmmAccess* access_flags_ptr) {
-    return true;
-  }
+  virtual bool ExportShareableVMMHandle(amd::Memory& amd_mem_obj, int flags, void* shareableHandle);
+
+  virtual amd::Memory* ImportShareableVMMHandle(void* osHandle);
 
   //! Returns SRD manger object
   SrdManager& srds() const { return *srdManager_; }
@@ -738,5 +748,5 @@ class Device : public NullDevice {
   amd::Program* trap_handler_ = nullptr;  //!< Trap handler program for debugger setup
 };
 
-/*@}*/  // namespace pal
-}  // namespace pal
+/*@}*/  // namespace amd::pal
+}  // namespace amd::pal
