@@ -38,7 +38,7 @@
 #include "platform/interop_gl.hpp"
 #include "platform/external_memory.hpp"
 
-namespace roc {
+namespace amd::roc {
 
 // ======================================= roc::Memory ============================================
 Memory::Memory(const roc::Device& dev, amd::Memory& owner)
@@ -615,13 +615,13 @@ Buffer::Buffer(const roc::Device& dev, size_t size) : roc::Memory(dev, size) {}
 
 Buffer::~Buffer() {
   if (owner() == nullptr) {
-    dev().hostFree(deviceMemory_, size());
+    dev().memFree(deviceMemory_, size());
   } else {
     destroy();
 
     if (owner()->ipcShared()) {
       // Detach the memory from HSA
-      auto hsa_status = hsa_amd_ipc_memory_detach(owner()->getHostMem());
+      auto hsa_status = hsa_amd_ipc_memory_detach(owner()->getSvmPtr());
       if (hsa_status != HSA_STATUS_SUCCESS) {
         LogPrintfError("HSA failed to detach memory with status: %d \n", hsa_status);
       }
@@ -648,6 +648,12 @@ void Buffer::destroy() {
     }
     const bool isFineGrain = memFlags & CL_MEM_SVM_FINE_GRAIN_BUFFER;
 
+    if (memFlags & ROCCLR_MEM_PHYMEM) {
+      // If this is physical memory, dont call hsa free function, since device mem was never created
+      dev().deviceVmemRelease(owner()->getUserData().hsa_handle);
+      return;
+    }
+
     if (kind_ != MEMORY_KIND_PTRGIVEN) {
       if (isFineGrain) {
         if (memFlags & CL_MEM_ALLOC_HOST_PTR) {
@@ -657,7 +663,7 @@ void Buffer::destroy() {
               ClPrint(amd::LOG_DEBUG, amd::LOG_MEM, "[ROCClr] munmap failed \n");
             }
           } else {
-            dev().hostFree(deviceMemory_, size());
+            dev().memFree(deviceMemory_, size());
           }
         } else if (memFlags & ROCCLR_MEM_HSA_SIGNAL_MEMORY) {
           if (HSA_STATUS_SUCCESS != hsa_signal_destroy(signal_)) {
@@ -666,7 +672,7 @@ void Buffer::destroy() {
           }
           deviceMemory_ = nullptr;
         } else {
-          dev().hostFree(deviceMemory_, size());
+          dev().memFree(deviceMemory_, size());
         }
       } else {
         dev().memFree(deviceMemory_, size());
@@ -682,15 +688,12 @@ void Buffer::destroy() {
   }
 
   if (deviceMemory_ != nullptr) {
+    bool needUnlockHostMem = false;
     if (deviceMemory_ != owner()->getHostMem()) {
       // if they are identical, the host pointer will be
       // deallocated later on => avoid double deallocation
       if (isHostMemDirectAccess()) {
-        if (memFlags & (CL_MEM_USE_HOST_PTR | CL_MEM_ALLOC_HOST_PTR)) {
-          if (dev().agent_profile() != HSA_PROFILE_FULL) {
-            hsa_amd_memory_unlock(owner()->getHostMem());
-          }
-        }
+        needUnlockHostMem = true;
       } else {
         dev().memFree(deviceMemory_, size());
         const_cast<Device&>(dev()).updateFreeMemory(size(), true);
@@ -705,6 +708,15 @@ void Buffer::destroy() {
       } else if ((memFlags & CL_MEM_ALLOC_HOST_PTR) &&
                  (owner()->getContext().devices().size() == 1)) {
         dev().hostFree(deviceMemory_, size());
+      } else if (isHostMemDirectAccess()) {
+        needUnlockHostMem = true;
+      }
+    }
+
+    if (needUnlockHostMem) {
+      if (memFlags & (CL_MEM_USE_HOST_PTR | CL_MEM_ALLOC_HOST_PTR)) {
+        if (dev().agent_profile() != HSA_PROFILE_FULL)
+          hsa_amd_memory_unlock(owner()->getHostMem());
       }
     }
   }
@@ -757,11 +769,28 @@ bool Buffer::create(bool alloc_local) {
   cl_mem_flags memFlags = owner()->getMemFlags();
 
   if (memFlags & ROCCLR_MEM_PHYMEM) {
-    // If this is physical memory request, then get an handle and store it in user data
-    owner()->getUserData().hsa_handle = dev().deviceVmemAlloc(owner()->getSize(), 0);
+    if (memFlags & ROCCLR_MEM_INTERPROCESS) {
+      int dmabuf_fd = *(reinterpret_cast<int*>(owner()->getSvmPtr()));
+      // if interprocess flag is set, then the memory is importable.
+      if (!dev().ImportShareableHSAHandle(owner()->getSvmPtr(),
+            &owner()->getUserData().hsa_handle)) {
+        LogPrintfError("Importing Shareable Memory failed with os_handle: 0x%x \n",
+                        owner()->getSvmPtr());
+        return false;
+      }
+    } else {
+      // If this is physical memory request, then get an handle and store it in user data
+      owner()->getUserData().hsa_handle = dev().deviceVmemAlloc(owner()->getSize(), 0);
+    }
+
     if (owner()->getUserData().hsa_handle == 0) {
       LogError("HSA Opaque Handle returned was null");
+      return false;
     }
+
+    owner()->setSvmPtr(reinterpret_cast<void*>(owner()->getUserData().hsa_handle));
+
+    return true;
   }
 
   if ((owner()->parent() == nullptr) &&
@@ -771,7 +800,7 @@ bool Buffer::create(bool alloc_local) {
     }
     const bool isFineGrain = memFlags & CL_MEM_SVM_FINE_GRAIN_BUFFER;
 
-    if (isFineGrain) {
+    if (isFineGrain && !(memFlags & CL_MEM_VA_RANGE_AMD)) {
       // Use CPU direct access for the fine grain buffer
       flags_ |= HostMemoryDirectAccess;
     }
@@ -827,7 +856,8 @@ bool Buffer::create(bool alloc_local) {
       } else {
         assert(!isHostMemDirectAccess() && "Runtime doesn't support direct access to GPU memory!");
         deviceMemory_ = dev().deviceLocalAlloc(size(), (memFlags & CL_MEM_SVM_ATOMICS) != 0,
-                                               (memFlags & ROCCLR_MEM_HSA_UNCACHED) != 0);
+                                               (memFlags & ROCCLR_MEM_HSA_UNCACHED) != 0,
+                                               (memFlags & ROCCLR_MEM_HSA_CONTIGUOUS) != 0);
       }
       owner()->setSvmPtr(deviceMemory_);
     } else {
